@@ -7,12 +7,8 @@ class GoogleLatitude : public QObject {
     Q_OBJECT
 
 signals:
-    void setOK();
-    void setERROR();
-    void getOK();
-
-public slots:
-    void get();    
+    void OK();
+    void ERROR();
 
 public:
     GoogleLatitude(QObject *parent = 0);
@@ -37,7 +33,6 @@ private:
     QUrl urllogin;
     QUrl urldologin;
     QUrl urlupdate;
-    QUrl urlloc;
 };
 
 #endif // GLATITUDE_H
