@@ -3,9 +3,9 @@
 
 #include <QtGui>
 #include <QtWebKit>
+#include <QtMaemo5>
 #include "glatitude.h"
 #include "gps.h"
-#include "gpsfake.h"
 
 class LatitudeGUI : public QMainWindow {
     Q_OBJECT
@@ -17,33 +17,21 @@ public:
     LatitudeGUI(QMainWindow *parent = 0);
 
 private slots:
-    void get_loc();
-    void get_acwp();
-    void get_agnss();
-    void get_maemo5();
     void set();
-    void set_OK();
-    void set_ERROR();
-    void save();
-    void show_map();
-    void show_lat();
+    void latitude_OK();
+    void latitude_ERROR();
+    void save_user(QString);
+    void save_pass(QString);
     void maps_login();
+    void mode_buzz();
+    void mode_latitude();
 
 private:
     GoogleLatitude *glatitude;
     GpsMaemo5 *gps;
     QSettings *setting;
     QWebView *maps;
-    QWidget *location;
-    QUrl urllogin;
-
-    QLineEdit *login_user;
-    QLineEdit *login_pass;
-    QLineEdit *location_lat;
-    QLineEdit *location_lon;
-    QLineEdit *location_acc;
-
-    QLineEdit *status;
+    QUrl url;
 };
 
 #endif // LATITUDE_H
